Struct indy_data_types::anoncreds::presentation::AttributeValue
source · pub struct AttributeValue {
pub raw: String,
pub encoded: String,
}Fields
raw: Stringencoded: StringTrait Implementations
sourceimpl Clone for AttributeValue
impl Clone for AttributeValue
sourcefn clone(&self) -> AttributeValue
fn clone(&self) -> AttributeValue
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for AttributeValue
impl Debug for AttributeValue
sourceimpl<'de> Deserialize<'de> for AttributeValue
impl<'de> Deserialize<'de> for AttributeValue
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Ord for AttributeValue
impl Ord for AttributeValue
sourcefn cmp(&self, other: &AttributeValue) -> Ordering
fn cmp(&self, other: &AttributeValue) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for AttributeValue
impl PartialEq for AttributeValue
sourcefn eq(&self, other: &AttributeValue) -> bool
fn eq(&self, other: &AttributeValue) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for AttributeValue
impl PartialOrd for AttributeValue
sourcefn partial_cmp(&self, other: &AttributeValue) -> Option<Ordering>
fn partial_cmp(&self, other: &AttributeValue) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for AttributeValue
impl Serialize for AttributeValue
impl Eq for AttributeValue
impl StructuralEq for AttributeValue
impl StructuralPartialEq for AttributeValue