Struct indy_data_types::anoncreds::presentation::SubProofReferent
source · pub struct SubProofReferent {
pub sub_proof_index: u32,
}Fields
sub_proof_index: u32Trait Implementations
sourceimpl Clone for SubProofReferent
impl Clone for SubProofReferent
sourcefn clone(&self) -> SubProofReferent
fn clone(&self) -> SubProofReferent
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for SubProofReferent
impl Debug for SubProofReferent
sourceimpl<'de> Deserialize<'de> for SubProofReferent
impl<'de> Deserialize<'de> for SubProofReferent
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Ord for SubProofReferent
impl Ord for SubProofReferent
sourcefn cmp(&self, other: &SubProofReferent) -> Ordering
fn cmp(&self, other: &SubProofReferent) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for SubProofReferent
impl PartialEq for SubProofReferent
sourcefn eq(&self, other: &SubProofReferent) -> bool
fn eq(&self, other: &SubProofReferent) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for SubProofReferent
impl PartialOrd for SubProofReferent
sourcefn partial_cmp(&self, other: &SubProofReferent) -> Option<Ordering>
fn partial_cmp(&self, other: &SubProofReferent) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for SubProofReferent
impl Serialize for SubProofReferent
impl Eq for SubProofReferent
impl StructuralEq for SubProofReferent
impl StructuralPartialEq for SubProofReferent