[−][src]Module indy_data_types::keys
Indy signing keys and verification keys
Structs
| ArrayKey | A secure key representation for fixed-length keys |
| EncodedVerKey | An encoded verkey appropriate for storing and transmitting |
| PrivateKey | A raw signing key used for generating transaction signatures |
| VerKey | A raw verkey used in verifying signatures |
Enums
| KeyEncoding | Enum of known and unknown key encodings |
| KeyType | Enum of known and unknown key types |
Functions
| build_full_verkey | Build an encoded verkey |