pub enum AbstractQuery<K, V> {
And(Vec<Self>),
Or(Vec<Self>),
Not(Box<Self>),
Eq(K, V),
Neq(K, V),
Gt(K, V),
Gte(K, V),
Lt(K, V),
Lte(K, V),
Like(K, V),
In(K, Vec<V>),
Exist(Vec<K>),
}Expand description
An abstract query representation over a key and value type
Variants
And(Vec<Self>)
Logical AND of multiple clauses
Or(Vec<Self>)
Logical OR of multiple clauses
Not(Box<Self>)
Negation of a clause
Eq(K, V)
Equality comparison for a field value
Neq(K, V)
Inequality comparison for a field value
Gt(K, V)
Greater-than comparison for a field value
Gte(K, V)
Greater-than-or-equal comparison for a field value
Lt(K, V)
Less-than comparison for a field value
Lte(K, V)
Less-than-or-equal comparison for a field value
Like(K, V)
SQL ‘LIKE’-compatible string comparison for a field value
In(K, Vec<V>)
Match one of multiple field values in a set
Exist(Vec<K>)
Match any non-null field value of the given field names
Implementations
Sourceimpl<K, V> AbstractQuery<K, V>
impl<K, V> AbstractQuery<K, V>
Sourcepub fn map_names<RK, E>(
self,
f: impl FnMut(K) -> Result<RK, E>,
) -> Result<AbstractQuery<RK, V>, E>
pub fn map_names<RK, E>( self, f: impl FnMut(K) -> Result<RK, E>, ) -> Result<AbstractQuery<RK, V>, E>
Perform a transformation on all field names in query clauses
Sourcepub fn map_values<RV, E>(
self,
f: impl FnMut(&K, V) -> Result<RV, E>,
) -> Result<AbstractQuery<K, RV>, E>
pub fn map_values<RV, E>( self, f: impl FnMut(&K, V) -> Result<RV, E>, ) -> Result<AbstractQuery<K, RV>, E>
Perform a transformation on all field values in query clauses